@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,6 +26,7 @@
 
 #include <string.h>
 
+#include "yelp-cache.h"
 #include "yelp-window.h"
 #include "yelp-section.h"
 #include "yelp-scrollkeeper.h"
@@ -34,7 +35,7 @@
 #include "yelp-base.h"
 
 typedef struct {
-	YelpBase     *base;
+	YelpBase    *base;
 	GtkTreeIter *parent;
 } ForeachData;
 
@@ -85,7 +86,7 @@ impl_Yelp_getWindows (PortableServer_Servant  servant,
 	GNOME_Yelp_WindowList *list;
 	gint                   len, i;
 	GSList                *node;
-	const gchar           *url;
+	YelpURI               *uri;
 	
 	base = YELP_BASE (bonobo_object (servant));
 	priv = base->priv;
@@ -99,8 +100,12 @@ impl_Yelp_getWindows (PortableServer_Servant  servant,
 	CORBA_sequence_set_release (list, CORBA_TRUE);
 	
 	for (node = priv->windows, i = 0; node; node = node->next, i++) {
-		url = yelp_window_get_current_uri (YELP_WINDOW (node->data));
-		list->_buffer[i] = CORBA_string_dup (url);
+		gchar *str_uri;
+
+		uri = yelp_window_get_current_uri (YELP_WINDOW (node->data));
+		str_uri = yelp_uri_to_string (uri);
+		list->_buffer[i] = CORBA_string_dup (str_uri);
+		g_free (str_uri);
 	}
 	
 	return list;
@@ -117,6 +122,8 @@ yelp_base_init (YelpBase *base)
 	priv->index    = NULL;
 	priv->windows  = NULL;
         base->priv     = priv;
+
+	yelp_cache_init ();
 }
 
 static void
